{
"name": "{{ project_name }}",
"short_name": "{{ project_slug }}",
"icons": [
  {
    "src": "/static/favicons/android-chrome-192x192.png",
    "sizes": "192x192",
    "type": "image/png"
  },
  {
    "src": "/static/favicons/android-chrome-512x512.png",
    "sizes": "512x512",
    "type": "image/png"
  }
],
"theme_color": "#ffffff",
"background_color": "#ffffff",
"display": "standalone"
}
